RAMP workflow
=============

RAMP workflow allows to define and run machine learning pipeline, documentations available here_.

.. _here: https://paris-saclay-cds.github.io/ramp-docs/ramp-workflow/stable/ 
